# xmle
An extension to xml.etree.ElementTree.Element to handle xml snippets

This library aids in generating neatly formatted HTML output from a
variety of object types.

Check out some examples in the ``Example.ipynb`` notebook.